@@ -22,8 +22,7 @@
 #define __CKSUM_H__
 
 #include <stdint.h>
-#include <stddef.h>
 
-uint16_t cksum(void *, size_t);
+uint16_t cksum(void *, uint32_t);
 
 #endif
