@@ -35,6 +35,7 @@ enum
 
   OPTION_VERSION,
   OPTION_HELP,
+  OPTION_QUIET,
 
   /* XXX COMMON OPTIONS                            */
   OPTION_THRESHOLD,
@@ -298,6 +299,7 @@ struct config_options
   _Bool     encapsulated;           /* GRE encapsulated            */
   _Bool     bogus_csum;             /* bogus packet checksum       */
   _Bool     shuffle;                /* Shuffling option for T50 proto. */
+  _Bool     quiet;                  /* Non-verbose mode. */
 #ifdef  __HAVE_TURBO__
   _Bool     turbo;                  /* duplicate the attack        */
 #endif  /* __HAVE_TURBO__ */
@@ -581,7 +583,7 @@ struct options_table_s
   int id;             /* This is the value returned by find_option(). */
   char short_opt;     /* Single char short option (ou '\0' if none). */
   char *long_opt;     /* String for long option name (or NULL is none.) */
-  int has_arg;        /* If option must have an argument, this is 1. */
+  _Bool has_arg;      /* If option must have an argument, this is 1. */
 
   /* "private" part. */
   _Bool in_use_;      /* Boolean used to check if option was already used. */
