@@ -28,7 +28,7 @@
 #include <t50_modules.h>
 #include <t50_randomizer.h>
 
-static size_t eigrp_hdr_len(const uint16_t, const uint16_t, const uint8_t, const int);
+static uint32_t eigrp_hdr_len(const uint16_t, const uint16_t, const uint8_t, const int);
 
 /**
  * EIGRP packet header configuration.
@@ -38,9 +38,9 @@ static size_t eigrp_hdr_len(const uint16_t, const uint16_t, const uint8_t, const
  * @param co Pointer to T50 configuration structure.
  * @param size Pointer to packet size (updated by the function).
  */
-void eigrp(const struct config_options *const __restrict__ co, size_t *size)
+void eigrp(const struct config_options *const __restrict__ co, uint32_t *size)
 {
-  size_t greoptlen,     /* GRE options size. */
+  uint32_t length,
          eigrp_tlv_len, /* EIGRP TLV size. */
          counter;
 
@@ -55,15 +55,15 @@ void eigrp(const struct config_options *const __restrict__ co, size_t *size)
 
   assert(co != NULL);
 
-  greoptlen = gre_opt_len(co);
+  length = gre_opt_len(co);
   prefix = __RND(co->eigrp.prefix);
   eigrp_tlv_len = eigrp_hdr_len(co->eigrp.opcode, co->eigrp.type, prefix, co->eigrp.auth);
 
   *size = sizeof(struct iphdr)     +
           sizeof(struct eigrp_hdr) +
           eigrp_tlv_len            +
-          greoptlen                +
-          8;    /* OBS: Ugly workaround! Must change this later! */
+          length                   +
+          8;    /* FIXME: Ugly workaround! Must change this later! */
 
   /* Try to reallocate packet, if necessary */
   alloc_packet(*size);
@@ -89,7 +89,7 @@ void eigrp(const struct config_options *const __restrict__ co, size_t *size)
    *
    * EIGRP Header structure.
    */
-  eigrp              = (struct eigrp_hdr *)((unsigned char *)(ip + 1) + greoptlen);
+  eigrp              = (struct eigrp_hdr *)((unsigned char *)(ip + 1) + length);
   eigrp->version     = co->eigrp.ver_minor ? co->eigrp.ver_minor : EIGRPVERSION;
   eigrp->opcode      = __RND(co->eigrp.opcode);
   eigrp->flags       = __RND(co->eigrp.flags);
@@ -117,7 +117,7 @@ void eigrp(const struct config_options *const __restrict__ co, size_t *size)
           co->eigrp.type  == EIGRP_TYPE_SOFTWARE)))
     {
       /* NOTE: stemp used to avoid multiple comparisons on loop below */
-      size_t stemp;
+      uint32_t stemp;
 
       stemp = auth_hmac_md5_len(co->eigrp.auth);
 
@@ -427,22 +427,23 @@ void eigrp(const struct config_options *const __restrict__ co, size_t *size)
   }
 
   /* Computing the checksum. */
+  length = (uint32_t)(buffer.ptr - (void *)eigrp);
   eigrp->check    = co->bogus_csum ?
-                    RANDOM() : cksum(eigrp, buffer.ptr - (void *)eigrp);
+                    RANDOM() : cksum(eigrp, length);
 
   /* GRE Encapsulation takes place. */
   gre_checksum(packet, co, *size);
 }
 
 /* EIGRP header size calculation */
-size_t eigrp_hdr_len(const uint16_t opcode,
+uint32_t eigrp_hdr_len(const uint16_t opcode,
                      const uint16_t type,
                      const uint8_t prefix,
                      const int auth)
 {
   /* The code starts with size '0' and it accumulates all the required
    * size if the conditionals match. Otherwise, it returns size '0'. */
-  size_t size = 0;
+  uint32_t size = 0;
 
   /*
    * The Authentication Data TVL must be used only in some cases:
