@@ -34,7 +34,7 @@
 /*
  * prototypes.
  */
-static size_t tcp_options_len(const uint8_t, int, int);
+static uint32_t tcp_options_len(const uint8_t, int, int);
 
 /**
  * TCP packet header configuration.
@@ -45,10 +45,9 @@ static size_t tcp_options_len(const uint8_t, int, int);
  * @param co Pointer to T50 configuration structure.
  * @param size Pointer to size of the packet (updated by the function).
  */
-void tcp(const struct config_options *const __restrict__ co, size_t *size)
+void tcp(const struct config_options *const __restrict__ co, uint32_t *size)
 {
-  size_t greoptlen,   /* GRE options size. */
-         tcpolen,     /* TCP options size. */
+  uint32_t tcpolen,     /* TCP options size. */
          tcpopt,      /* TCP options total size. */
          length,
          counter;
@@ -66,7 +65,7 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
 
   assert(co != NULL);
 
-  greoptlen = gre_opt_len(co);
+  length = gre_opt_len(co);
   tcpolen = tcp_options_len(co->tcp.options, co->tcp.md5, co->tcp.auth);
   tcpopt = tcpolen + TCPOLEN_PADDING(tcpolen);
 
@@ -74,7 +73,7 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
           sizeof(struct tcphdr) +
           sizeof(struct psdhdr) +
           tcpopt                +
-          greoptlen;
+          length;
 
   /* Try to reallocate packet, if necessary */
   alloc_packet(*size);
@@ -98,7 +97,7 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
                 __FUNCTION__, tcpopt);
 
   /* TCP Header structure making a pointer to IP Header structure. */
-  tcp          = (struct tcphdr *)((unsigned char *)(ip + 1) + greoptlen);
+  tcp          = (struct tcphdr *)((unsigned char *)(ip + 1) + length);
   tcp->source  = IPPORT_RND(co->source);
   tcp->dest    = IPPORT_RND(co->dest);
   tcp->res1    = TCP_RESERVED_BITS;
@@ -382,7 +381,7 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
    */
   if (co->tcp.md5)
   {
-    size_t stemp; /* Used to do just one call to auth_hmac_md5_len(). */
+    uint32_t stemp; /* Used to do just one call to auth_hmac_md5_len(). */
 
     *buffer.byte_ptr++ = TCPOPT_MD5;
     *buffer.byte_ptr++ = TCPOLEN_MD5;
@@ -419,7 +418,7 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
    */
   if (co->tcp.auth)
   {
-    size_t stemp; /* Used to do just one call to auth_hmac_md5_len(). */
+    uint32_t stemp; /* Used to do just one call to auth_hmac_md5_len(). */
 
     *buffer.byte_ptr++ = TCPOPT_AO;
     *buffer.byte_ptr++ = TCPOLEN_AO;
@@ -463,15 +462,16 @@ void tcp(const struct config_options *const __restrict__ co, size_t *size)
   length += sizeof(struct psdhdr);
 
   /* Computing the checksum. */
-  tcp->check   = co->bogus_csum ? RANDOM() : cksum(tcp, length);
+  tcp->check   = co->bogus_csum ? RANDOM() : 
+                 cksum(tcp, length);
 
   gre_checksum(packet, co, *size);
 }
 
 /* TCP options size calculation. */
-size_t tcp_options_len(const uint8_t tcp_options, int useMD5, int useAuth)
+uint32_t tcp_options_len(const uint8_t tcp_options, int useMD5, int useAuth)
 {
-  size_t size;
+  uint32_t size;
 
   /*
    * The code starts with size '0' and it accumulates all the required
